## Niclas Schlapmann - Freelance 3D Technical Artist
## www.enoni.de
## hello@enoni.de
## ns_Version::ns_add_cam_slate_info
## 27.11.2021


import hou

sel = hou.selectedNodes()

if sel:
	## focus null ##
	focus_null = sel[0].parent().createNode("null", sel[0].name() + "_focus")
	focus_null.setPosition(sel[0].position() + hou.Vector2(-1, -2))
	focus_null.setInput(0, sel[0])
	focus_null.setParms({"controltype" : 3,
						 "orientation" : 3,
						 "constraints_on" : 1,
						 "constraints_path": "constraints",
						 "tz" : -1})
	focus_null.setParms({"geosizey" : sel[0].parm("resy").eval() / sel[0].parm("resx").eval()})
	
	## constraint chop ##
	chop_constr_net = focus_null.createNode("chopnet", "constraints")
	
	chop_worldspace = chop_constr_net.createNode("constraintgetworldspace", "getworldspace")
	chop_worldspace.setParms({
		"obj_path" : "../..",
		"vex_range": 1
		})
	chop_worldspace_sample_rate_parm = chop_worldspace.parm("vex_rate")
	chop_worldspace_sample_rate_parm.setExpression('''$CHOPMOTIONSAMPLES*$FPS''')

	chop_object = chop_constr_net.createNode("constraintobject", "cam")
	chop_object.setParms({
		"obj_path" : "../../../" + sel[0].name(),
		"vex_range": 1
		})
	chop_object_sample_rate_parm = chop_object.parm("vex_rate")
	chop_object_sample_rate_parm.setExpression('''$CHOPMOTIONSAMPLES*$FPS''')

	chop_look_at = chop_constr_net.createNode("constraintlookat", "lookat")
	chop_look_at.setParms({"mode" : 1})
	chop_look_at_sample_rate_parm = chop_look_at.parm("vex_rate")
	chop_look_at_sample_rate_parm.setExpression('''$CHOPMOTIONSAMPLES*$FPS''')
	chop_look_at.setInput(0, chop_worldspace)
	chop_look_at.setInput(1, chop_object)
	chop_look_at.setAudioFlag(True) 

	chop_worldspace.moveToGoodPosition()
	chop_object.moveToGoodPosition()
	chop_look_at.moveToGoodPosition()


	## line obj ##
	line_geo = sel[0].parent().createNode("geo", sel[0].name() + "_line")
	line_geo.setPosition(sel[0].position() + hou.Vector2(1, -1.5))
	line_geo.setInput(0, sel[0])

	add_node = line_geo.createNode("add")
	measure_node = line_geo.createNode("measure")
	measure_node.setPosition(add_node.position() + hou.Vector2(0, -1))
	measure_node.setInput(0, add_node)
	null_out = line_geo.createNode("null", "OUT")
	null_out.setPosition(measure_node.position() + hou.Vector2(0, -1))
	null_out.setInput(0, measure_node)
	null_out.setDisplayFlag(True)

	add_node.setParms({"points" : 2})
	add_node.setParms({"usept0" : 1})
	add_node.setParms({"usept1" : 1})
	add_node.parm("stdswitcher1").set(1)
	add_node.parm("switcher1").set(1)

	## world space pts expressions ##
	pt0x_parm = add_node.parm("pt0x")
	pt0x_parm.setExpression('''{

matrix src_xform = optransform("''' + sel[0].path() + '''");
matrix target_xform_inverted = invert(optransform(opcreator(".")));
matrix final_xform = src_xform * target_xform_inverted;


float rest_value = 0.000000;
float xform_comp = final_xform[3][0];
float result = rest_value + xform_comp;
return result;

}''')
	pt0y_parm = add_node.parm("pt0y")
	pt0y_parm.setExpression('''{

matrix src_xform = optransform("''' + sel[0].path() + '''");
matrix target_xform_inverted = invert(optransform(opcreator(".")));
matrix final_xform = src_xform * target_xform_inverted;


float rest_value = 0.000000;
float xform_comp = final_xform[3][1];
float result = rest_value + xform_comp;
return result;

}''')
	pt0z_parm = add_node.parm("pt0z")
	pt0z_parm.setExpression('''{

matrix src_xform = optransform("''' + sel[0].path() + '''");
matrix target_xform_inverted = invert(optransform(opcreator(".")));
matrix final_xform = src_xform * target_xform_inverted;


float rest_value = 0.000000;
float xform_comp = final_xform[3][2];
float result = rest_value + xform_comp;
return result;

}''')
	pt1x_parm = add_node.parm("pt1x")
	pt1x_parm.setExpression('''{

matrix src_xform = optransform("''' + sel[0].path() + "_focus" + '''");
matrix target_xform_inverted = invert(optransform(opcreator(".")));
matrix final_xform = src_xform * target_xform_inverted;


float rest_value = 0.000000;
float xform_comp = final_xform[3][0];
float result = rest_value + xform_comp;
return result;

}''')
	pt1y_parm = add_node.parm("pt1y")
	pt1y_parm.setExpression('''{

matrix src_xform = optransform("''' + sel[0].path() + "_focus" + '''");
matrix target_xform_inverted = invert(optransform(opcreator(".")));
matrix final_xform = src_xform * target_xform_inverted;


float rest_value = 0.000000;
float xform_comp = final_xform[3][1];
float result = rest_value + xform_comp;
return result;

}''')
	pt1z_parm = add_node.parm("pt1z")
	pt1z_parm.setExpression('''{

matrix src_xform = optransform("''' + sel[0].path() + "_focus" + '''");
matrix target_xform_inverted = invert(optransform(opcreator(".")));
matrix final_xform = src_xform * target_xform_inverted;


float rest_value = 0.000000;
float xform_comp = final_xform[3][2];
float result = rest_value + xform_comp;
return result;

}''')

measure_node.setParms({"measure" : 0,
					   "attribname" : "focus_distance"})


## cam focus distance ##
focus_parm = sel[0].parm("focus")
focus_parm.setExpression('''prim("''' + null_out.path() + '''", 0, "focus_distance", 0)''')